"use client"

import { faTimes } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { Dialog, Transition } from '@headlessui/react'
import HTMLReactParser from "html-react-parser";
import { Fragment, ReactNode } from 'react'


interface IModalProps {
	title: string
	isOpen: boolean;
	setIsOpen: (isOpen: boolean) => void;
	children: string | ReactNode
}

export default function Modal({ isOpen, setIsOpen, title, children }: IModalProps) {

	function closeModal() {
		setIsOpen(false)
	}

	function openModal() {
		setIsOpen(true)
	}

	return (
		<>


			<Transition appear show={isOpen} as={Fragment}>
				<Dialog as="div" className="relative z-50 " onClose={closeModal}>
					<Transition.Child
						as={Fragment}
						enter="ease-out duration-300"
						enterFrom="opacity-0"
						enterTo="opacity-100"
						leave="ease-in duration-200"
						leaveFrom="opacity-100"
						leaveTo="opacity-0"
					>
						<div className="fixed inset-0 bg-black bg-opacity-90" />
					</Transition.Child>

					<div className="fixed inset-0 overflow-y-auto">
						<div className="flex min-h-full items-center justify-center p-4 text-center">
							<Transition.Child
								as={Fragment}
								enter="ease-out duration-300"
								enterFrom="opacity-0 scale-95"
								enterTo="opacity-100 scale-100"
								leave="ease-in duration-200"
								leaveFrom="opacity-100 scale-100"
								leaveTo="opacity-0 scale-95"
							>
								<Dialog.Panel className="w-full max-w-2xl transform overflow-hidden rounded-2xl bg-gray-900 p-6 text-left align-middle shadow-xl border border-gray-800 transition-all">
									<p className="text-right">
										<button type="button" title="close modal" onClick={() => setIsOpen(false)}>
											<FontAwesomeIcon icon={faTimes} className="w-5 h-5 text-rfw-dark" />
										</button>
									</p>

									<Dialog.Title
										as="h3"
										className="text-2xl font-semibold leading-6 text-rfw-other"
									>
										{title}
									</Dialog.Title>
									<div className="mt-4 text-gray-400 text-lg">

										{HTMLReactParser(children as string)}
									</div>


								</Dialog.Panel>
							</Transition.Child>
						</div>
					</div>
				</Dialog>
			</Transition>
		</>
	)
}
